CameraPath class

An ordered sequence of CameraKeyframe values.

Constructors

CameraPath(List<CameraKeyframe> keyframes)

Properties

duration double
no setter
hashCode int
The hash code for this object.
no setterinherited
keyframes List<CameraKeyframe>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited