CameraRoom class

A bounded rectangular room definition for RoomBehavior.

Constructors

CameraRoom({required String id, required Rect bounds})
const

Properties

bounds Rect
final
center Offset
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited