CircleParticleRenderer class
Renders each particle as a filled circle.
- Inheritance
-
- Object
- ParticleRenderer
- CircleParticleRenderer
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Canvas canvas, Particle particle) → void -
Draw a single
particleontocanvas.override -
renderBatch(
Canvas canvas, List< Particle> particles) → void -
Draw all
particlesontocanvas.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited