getGraph method
Returns the registered graph for id, or null if not found.
Implementation
DialogueGraph? getGraph(String id) => _graphs[id];
Returns the registered graph for id, or null if not found.
DialogueGraph? getGraph(String id) => _graphs[id];