HierarchySystem class

Parent-child system - Updates child transforms based on parents

Inheritance

Constructors

HierarchySystem()

Properties

entities Iterable<Entity>
Get all entities that match this system's requirements
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Whether this system is active
getter/setter pairinherited
priority int
Priority for system execution order (higher = earlier)
getter/setter pairinherited
requiredComponents List<Type>
Required component types for this system
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
world World
World this system belongs to
getter/setter pairinherited

Methods

dispose() → void
Dispose system resources
inherited
forEach(void action(Entity entity)) → void
Execute a function for each matching entity
inherited
initialize() → void
Initialize the system
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAddedToWorld() → void
Called when system is added to world
inherited
onRemovedFromWorld() → void
Called when system is removed from world
inherited
render(Canvas canvas, Size size) → void
Render the system (optional)
inherited
toString() String
A string representation of this object.
inherited
update(double deltaTime) → void
Update the system
override

Operators

operator ==(Object other) bool
The equality operator.
inherited