JustAdSize class

Named ad size constants that mirror google_mobile_ads without importing it.

Constructors

JustAdSize({required int width, required int height})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
isAdaptive bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

adaptive → const JustAdSize
Use this to request an anchored adaptive banner (fills screen width).
fullBanner → const JustAdSize
largeBanner → const JustAdSize
leaderboard → const JustAdSize
mediumRectangle → const JustAdSize