MusicManager class

Music manager (convenience wrapper)

Constructors

MusicManager(AudioEngine _engine)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
Pause music
play(String path, {double volume = 1.0, bool loop = true, bool fadeIn = false}) Future<void>
Play music
resume() Future<void>
Resume music
setVolume(double volume) → void
Set music channel volume
stop({bool fadeOut = false}) Future<void>
Stop music
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited