NetworkClient class

Handles client-side networking

Constructors

NetworkClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String host, int port) Future<void>
Connect to a server
disconnect() → void
Disconnect from server
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDataReceived() → void
Receive data from server
send(dynamic data) → void
Send data to server
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited