NetworkProtocol class

Handles network protocols

Constructors

NetworkProtocol()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserialize(dynamic data) → dynamic
Deserialize received data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(dynamic data) → dynamic
Serialize data for network transmission
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited