ParentComponent class
Parent-child component - Hierarchy relationships
Constructors
- ParentComponent({EntityId? parentId, Offset localOffset = Offset.zero, double localRotation = 0.0})
- Create a parent component
Properties
- componentType → Type
-
Type identifier for this component
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- localOffset ↔ Offset
-
Local offset from parent
getter/setter pair
- localRotation ↔ double
-
Local rotation offset
getter/setter pair
- parentId ↔ EntityId?
-
Parent entity ID (null if root)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited