ParticleShape enum
Shape enum — kept for backward compatibility.
Prefer constructing a ParticleRenderer subclass directly.
Note: ParticleEmitter.shape is deprecated; use ParticleEmitter.renderer instead.
- Inheritance
- Available extensions
Values
- circle → const ParticleShape
- square → const ParticleShape
- triangle → const ParticleShape
- star → const ParticleShape
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRenderer(
) → ParticleRenderer -
Available on ParticleShape, provided by the ParticleShapeRenderer extension
Returns a new ParticleRenderer instance for this shape. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ParticleShape> - A constant List of the values in this enum, in order of their declaration.