ChoiceSetStatement class
A set of player-selectable options at the same indentation level.
Corresponds to a contiguous run of -> lines in Yarn.
- Inheritance
-
- Object
- DialogueStatement
- ChoiceSetStatement
Constructors
-
ChoiceSetStatement({required List<
ChoiceOption> choices}) -
const
Properties
-
choices
→ List<
ChoiceOption> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited