onAttach method
Called when this component is added to an entity.
Override to perform setup that depends on the owning entity. The default implementation does nothing.
Implementation
void onAttach(EntityId entityId) {}
Called when this component is added to an entity.
Override to perform setup that depends on the owning entity. The default implementation does nothing.
void onAttach(EntityId entityId) {}