ImageAsset class
Image/Texture asset
Constructors
- ImageAsset(String path)
- Constructor
Properties
- data → Uint8List?
-
Get raw image data
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Image height
no setter
- image → Image?
-
Get the loaded image
no setter
- isLoaded → bool
-
Get load status
no setterinherited
- path → String
-
Asset identifier/path
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AssetType
-
Asset type
finalinherited
- width → int
-
Image width
no setter
Methods
-
getMemoryUsage(
) → int -
Get memory usage in bytes
override
-
load(
) → Future< void> -
Load the asset
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unload(
) → void -
Unload the asset and free resources
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited