InputManager class

Main input manager class

Constructors

InputManager()

Properties

controller ControllerInput
Controller input handler
final
hashCode int
The hash code for this object.
no setterinherited
keyboard KeyboardInput
Keyboard input handler
final
mouse MouseInput
Mouse input handler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
touch TouchInput
Touch input handler
final

Methods

clear() → void
Clear all input states
dispose() → void
Clean up input resources
handleKeyEvent(KeyEvent event) → void
Handle key event (call from widget)
handlePointerEvent(PointerEvent event) → void
Handle pointer event (call from widget)
initialize() → void
Initialize input system
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKeyEvent(void callback(KeyEvent)) → void
Register callback for key events
onPointerEvent(void callback(PointerEvent)) → void
Register callback for pointer events
toString() String
A string representation of this object.
inherited
update() → void
Update input state (call each frame)

Operators

operator ==(Object other) bool
The equality operator.
inherited