PhysicsEngine class

Main physics engine class

Constructors

PhysicsEngine()

Properties

bodies List<PhysicsBody>
Get all bodies
no setter
debugRender bool
Whether debug rendering is enabled
getter/setter pair
gravity Offset
Global gravity
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBody(PhysicsBody body) → void
Add a physics body
dispose() → void
Clean up physics resources
initialize() → void
Initialize the physics engine
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeBody(PhysicsBody body) → void
Remove a physics body
renderDebug(Canvas canvas, Size size) → void
Render debug visualization
toString() String
A string representation of this object.
inherited
update(double deltaTime) → void
Update physics simulation

Operators

operator ==(Object other) bool
The equality operator.
inherited