RigidBody class

Represents a rigid body in the physics simulation

Constructors

RigidBody()

Properties

hashCode int
The hash code for this object.
no setterinherited
mass double
Mass of the rigid body
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyForce(double x, double y, double z) → void
Apply force to the rigid body
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited