SceneEditor class
Main scene editor class
Constructors
Properties
- activeScene ↔ Scene?
-
Active scene
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sceneNames
→ List<
String> -
Get all scene names
no setter
Methods
-
createScene(
String name) → Scene - Create a new scene
-
dispose(
) → void - Clean up editor resources
-
initialize(
) → void - Initialize the scene editor
-
loadScene(
String name) → void - Load a scene
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Canvas canvas, Size size) → void - Render the active scene
-
saveScene(
String path) → void - Save the current scene
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
double deltaTime) → void - Update the active scene
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited